pyschism.cmd package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyschism.cmd.server

Submodules
----------

pyschism.cmd.argument\_parser module
------------------------------------

.. automodule:: pyschism.cmd.argument_parser
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.cmd.basecmd module
---------------------------

.. automodule:: pyschism.cmd.basecmd
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.cmd.plot\_mesh module
------------------------------

.. automodule:: pyschism.cmd.plot_mesh
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.cmd.plotting module
----------------------------

.. automodule:: pyschism.cmd.plotting
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.cmd.tidal\_run module
------------------------------

.. automodule:: pyschism.cmd.tidal_run
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyschism.cmd
   :members:
   :undoc-members:
   :show-inheritance:
